@@ -57,16 +57,12 @@ import java.util.Collection;
 import java.util.Collections;
 import java.util.HashSet;
 import java.util.List;
-import java.util.Map;
 import java.util.Set;
 import java.util.SortedSet;
 import java.util.TreeSet;
 import java.util.UUID;
 import com.amazonaws.AmazonClientException;
-import com.amazonaws.Request;
-import com.amazonaws.handlers.RequestHandler;
 import com.amazonaws.services.s3.AmazonS3Client;
-import com.amazonaws.services.s3.Headers;
 import com.amazonaws.services.s3.internal.BucketNameUtils;
 import com.amazonaws.services.s3.model.AbortMultipartUploadRequest;
 import com.amazonaws.services.s3.model.CompleteMultipartUploadRequest;
@@ -84,7 +80,6 @@ import com.amazonaws.services.s3.model.S3Object;
 import com.amazonaws.services.s3.model.S3ObjectSummary;
 import com.amazonaws.services.s3.model.UploadPartRequest;
 import com.amazonaws.services.s3.model.UploadPartResult;
-import com.amazonaws.util.TimingInfo;
 import com.openexchange.exception.OXException;
 import com.openexchange.java.Streams;
 import com.openexchange.java.Strings;
@@ -127,32 +122,7 @@ public class S3FileStorage implements FileStorage {
         this.amazonS3 = amazonS3;
         this.bucketName = bucketName;
         this.prefix = prefix;
-        amazonS3.addRequestHandler(new RequestHandler() {
-
-			@Override
-			public void beforeRequest(Request<?> request) {
-				// nothing to do
-			}
-
-			@Override
-			public void afterResponse(Request<?> request, Object response,
-					TimingInfo timingInfo) {
-				if (response instanceof ObjectMetadata) {
-					Map<String, Object> headers = ((ObjectMetadata)response).getRawMetadata();
-					if (headers.containsKey("Etag")) {
-						String etag = (String) headers.get("Etag");
-						etag = etag.replace("\"", "");
-						((ObjectMetadata)response).setHeader(Headers.ETAG, etag);
-					}
-				}
-			}
-
-			@Override
-			public void afterError(Request<?> request, Exception e) {
-				// nothing to do
-			}
-		});
-        LOG.info("S3 file storage initialized for \"" + bucketName + "/" + prefix + DELIMITER + "\"");
+        LOG.info("S3 file storage initialized for \"{}/{}{}\"", bucketName, prefix, DELIMITER);
     }
 
     @Override
@@ -405,8 +375,8 @@ public class S3FileStorage implements FileStorage {
     /**
      * Gets metadata for an existing file.
      *
-     * @param key The key of the file
-     * @return The metadata
+     * @param key The (full) key for the new file; no additional prefix will be prepended implicitly
+     * @return The upload ID for the multipart upload
      * @throws OXException
      */
     private ObjectMetadata getMetadata(String key) throws OXException {
